runAsync method
Runs inference asynchronously when the selected accelerator supports it.
Implementation
Future<List<Float32List>> runAsync(List<Float32List> inputs) {
throw UnsupportedError('CompiledModel is not supported on this platform.');
}
Runs inference asynchronously when the selected accelerator supports it.
Future<List<Float32List>> runAsync(List<Float32List> inputs) {
throw UnsupportedError('CompiledModel is not supported on this platform.');
}