LandmarkMixin mixin

Mixin providing normalized coordinate utilities for landmarks with x/y pixel coordinates.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
no setter
y double
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPixel(int imageWidth, int imageHeight) Point
Converts this landmark to a Point in pixel coordinates.
toString() String
A string representation of this object.
inherited
xNorm(int imageWidth) double
Returns the x coordinate normalized to 0.0..1.0 relative to imageWidth.
yNorm(int imageHeight) double
Returns the y coordinate normalized to 0.0..1.0 relative to imageHeight.

Operators

operator ==(Object other) bool
The equality operator.
inherited