SSDAnchorOptions class

SSD anchor configuration options for SSD-style detection models.

Mirrors the Python SSDAnchorOptions namedtuple. Used internally for generating anchor boxes in SSD-style TFLite detection models.

Constructors

SSDAnchorOptions({required int numLayers, required double minScale, required double maxScale, required int inputSizeHeight, required int inputSizeWidth, required double anchorOffsetX, required double anchorOffsetY, required List<int> strides, required List<double> aspectRatios, required bool reduceBoxesInLowestLayer, required double interpolatedScaleAspectRatio, required bool fixedAnchorSize})
Creates SSD anchor options.
const

Properties

anchorOffsetX double
X offset for anchor centers (typically 0.5).
final
anchorOffsetY double
Y offset for anchor centers (typically 0.5).
final
aspectRatios List<double>
Aspect ratios for anchor boxes.
final
fixedAnchorSize bool
Whether to use fixed anchor size (1x1).
final
hashCode int
The hash code for this object.
no setterinherited
inputSizeHeight int
Input image height in pixels.
final
inputSizeWidth int
Input image width in pixels.
final
interpolatedScaleAspectRatio double
Interpolated scale aspect ratio (0 to disable).
final
maxScale double
Maximum anchor scale (0.0-1.0).
final
minScale double
Minimum anchor scale (0.0-1.0).
final
numLayers int
Number of feature map layers (typically 4 for detection models).
final
reduceBoxesInLowestLayer bool
Whether to reduce boxes in the lowest layer.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strides List<int>
Feature map strides for each layer.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited