FlutterLitertWeb class

Web plugin registration for flutter_litert.

The actual web implementation is handled through conditional imports (dart.library.js_interop). This class just registers the plugin with Flutter's web plugin system.

Constructors

FlutterLitertWeb()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void