CoreMlDelegate class

CoreMl Delegate

Implemented types
Annotations
  • @Deprecated('Manual hardware-acceleration delegates are superseded by LiteRT Next. Use ' 'CompiledModel.fromFile / CompiledModel.fromBuffer with ' 'accelerators: {Accelerator.npu, Accelerator.gpu, Accelerator.cpu}, or ' 'CompiledModel.fromBufferWithGpuFallback. The Interpreter API itself remains ' 'supported for CPU inference. ' 'See https://developers.google.com/edge/litert/next/get_started; planned ' 'for removal in flutter_litert 4.0.0.')

Constructors

CoreMlDelegate({CoreMlDelegateOptions? options})
Creates a CoreML delegate with optional options.
factory

Properties

base Pointer<TfLiteDelegate>
Get pointer to TfLiteDelegate
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete() → void
Releases native CoreML delegate resources.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited