GpuDelegateOptions class

Metal Delegate options

Annotations
  • @Deprecated('Options for a deprecated delegate. Configure acceleration through ' 'CompiledModel (accelerators / Precision) instead. ' 'Planned for removal in flutter_litert 4.0.0.')

Constructors

GpuDelegateOptions({bool allowPrecisionLoss = false, int waitType = TFLGpuDelegateWaitType.TFLGpuDelegateWaitTypePassive, bool enableQuantization = true})
Creates default Metal delegate options.
factory

Properties

base Pointer<TFLGpuDelegateOptions>
Pointer to the underlying native options struct.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete() → void
Releases native resources for these options.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited