GpuDelegateV2 class

GPU delegate for Android

Implemented types
Annotations
  • @Deprecated('Manual hardware-acceleration delegates are superseded by LiteRT Next. Use ' 'CompiledModel.fromFile / CompiledModel.fromBuffer with ' 'accelerators: {Accelerator.gpu, Accelerator.cpu}, or ' 'CompiledModel.fromBufferWithGpuFallback. The Interpreter API itself remains ' 'supported for CPU inference. ' 'See https://developers.google.com/edge/litert/next/get_started; planned ' 'for removal in flutter_litert 4.0.0.')

Constructors

GpuDelegateV2({GpuDelegateOptionsV2? options})
Creates GpuDelegateV2 using the specified options. Uses default options if options is not specified.
factory

Properties

base Pointer<TfLiteDelegate>
Get pointer to TfLiteDelegate
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete() → void
Releases native GPU delegate resources.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited