hasActiveDelegate property

bool get hasActiveDelegate

Whether interpreter creation successfully applied a hardware delegate.

This can be false even when the supplied InterpreterOptions contained a delegate, because delegate application is best-effort and creation may retry with equivalent CPU-only options.

Implementation

bool get hasActiveDelegate => _hasActiveDelegate;