IsolateInterpreter class

Allows running LiteRT inference in a separate isolate.

Properties

address int
final
debugName String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state IsolateInterpreterState
no setter
stateChanges Stream<IsolateInterpreterState>
no setter

Methods

close() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(Object input, Object output) Future<void>
Run LiteRT model for single input and output.
runForMultipleInputs(List<Object> inputs, Map<int, Object> outputs) Future<void>
Run LiteRT model for multiple inputs and outputs.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({required int address, String debugName = 'TfLiteInterpreterIsolate'}) Future<IsolateInterpreter>