isReady property
bool
get
isReady
Returns true if the worker has been initialized and is ready for requests.
Implementation
bool get isReady => _initialized;
Returns true if the worker has been initialized and is ready for requests.
bool get isReady => _initialized;