workerDisposeOp property

String? get workerDisposeOp

The name of the operation to send to the isolate when disposing.

Override in subclasses to specify the dispose operation (e.g., 'dispose'). Return null if the isolate does not handle a dispose message.

Implementation

String? get workerDisposeOp => null;