cancel method

bool cancel()

Attempts to cancel the currently executing invoke call.

Returns true if cancellation was successfully requested. Has no effect if no invocation is in progress. Cancellation is not guaranteed, the model may complete before the request is processed.

Implementation

bool cancel() {
  checkState(!_closed, message: 'SignatureRunner is already closed.');
  return tfliteBinding.TfLiteSignatureRunnerCancel(_runner) ==
      TfLiteStatus.kTfLiteOk;
}