close method
void
close()
Destroys this signature runner and releases native resources.
Must be called before the Interpreter that created this runner is closed. After calling close, this object must not be used.
Implementation
void close() {
checkState(!_closed, message: 'SignatureRunner is already closed.');
tfliteBinding.TfLiteSignatureRunnerDelete(_runner);
_closed = true;
}