TfLiteGpuExperimentalFlags class abstract

Used to toggle experimental flags used in the delegate. Note that this is a bitmask, so the values should be 1, 2, 4, 8, ...etc.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

TFLITE_GPU_EXPERIMENTAL_FLAGS_CL_ONLY → const int
Enforces execution with the provided backend.
TFLITE_GPU_EXPERIMENTAL_FLAGS_ENABLE_QUANT → const int
Enables inference on quantized models with the delegate. NOTE: This is enabled in TfLiteGpuDelegateOptionsV2Default.
TFLITE_GPU_EXPERIMENTAL_FLAGS_ENABLE_SERIALIZATION → const int
Enable serialization of GPU kernels & model data. Speeds up initialization at the cost of space on disk. Delegate performs serialization the first time it is applied with a new model or inference params. Later initializations are fast. ModifyGraphWithDelegate will fail if data cannot be serialized.
TFLITE_GPU_EXPERIMENTAL_FLAGS_GL_ONLY → const int
TFLITE_GPU_EXPERIMENTAL_FLAGS_NONE → const int