isLoaded property
bool
get
isLoaded
Returns whether the custom op has been successfully loaded.
Implementation
static bool get isLoaded => _registration != null;
Returns whether the custom op has been successfully loaded.
static bool get isLoaded => _registration != null;