IsolateRpcHandler typedef
Handler for a single RPC operation running inside the isolate.
Receives the raw request message map and returns the value to send back as
the response result, or throws to send an error.
Implementation
typedef IsolateRpcHandler =
Future<Object?> Function(Map<dynamic, dynamic> message);