LandmarkMixin mixin
Mixin providing normalized coordinate utilities for landmarks with x/y pixel coordinates.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toPixel(
int imageWidth, int imageHeight) → Point - Converts this landmark to a Point in pixel coordinates.
-
toString(
) → String -
A string representation of this object.
inherited
-
xNorm(
int imageWidth) → double -
Returns the x coordinate normalized to
0.0..1.0relative toimageWidth. -
yNorm(
int imageHeight) → double -
Returns the y coordinate normalized to
0.0..1.0relative toimageHeight.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited