lastNativeInferenceDurationMicroSeconds property
- @Deprecated('Use lastInferenceDurationMicroseconds instead. ' 'This alias will be removed in a future major release.')
Duration of the last native inference call in microseconds.
Deprecated in favor of lastInferenceDurationMicroseconds, which uses a platform-neutral name and consistent microseconds casing.
Implementation
@Deprecated(
'Use lastInferenceDurationMicroseconds instead. '
'This alias will be removed in a future major release.',
)
int get lastNativeInferenceDurationMicroSeconds =>
lastInferenceDurationMicroseconds;