InterpreterFactory class
Factory for creating interpreter options with the package's platform delegate mapping.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
PerformanceConfig? config, {bool addMediaPipeCustomOps = false}) → (InterpreterOptions, Delegate?) -
Creates InterpreterOptions and an optional Delegate based on
config. -
createIsolateIfNeeded(
Interpreter interpreter, Delegate? delegate, {bool useIsolateInterpreter = true}) → Future< IsolateInterpreter?> - Creates an IsolateInterpreter if conditions allow isolate-based inference.