InterpreterOptions class
LiteRT interpreter options.
Constructors
- InterpreterOptions()
-
Creates a new options instance.
factory
Properties
-
base
→ Pointer<
TfLiteInterpreterOptions> -
no setter
- hasDelegate → bool
-
Whether a delegate has been added via addDelegate.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- threads ↔ int?
-
Configured CPU thread count, or null when the runtime default is used.
getter/setter pair
Methods
-
addCustomOp<
T extends NativeType> ({required String name, required Pointer< T> registration, int minVersion = 1, int maxVersion = 1}) → void - Registers a custom op with these interpreter options.
-
addDelegate(
Delegate delegate) → void - Adds delegate to Interpreter Options
-
addMediaPipeCustomOps(
) → void - Registers MediaPipe custom ops (like Convolution2DTransposeBias).
-
copyWithoutDelegates(
) → InterpreterOptions - Creates equivalent options without hardware delegates.
-
delete(
) → void - Destroys the options instance.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited