TfLiteGpuInferenceUsage class abstract
Encapsulated compilation/runtime tradeoffs.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- TFLITE_GPU_INFERENCE_PREFERENCE_BALANCED → const int
- Balance init latency and throughput. This option will result in slightly higher init latency than FAST_SINGLE_ANSWER but should have inference latency closer to SUSTAINED_SPEED.
- TFLITE_GPU_INFERENCE_PREFERENCE_FAST_SINGLE_ANSWER → const int
- Delegate will be used only once, therefore, bootstrap/init time should be taken into account.
- TFLITE_GPU_INFERENCE_PREFERENCE_SUSTAINED_SPEED → const int
- Prefer maximizing the throughput. Same delegate will be used repeatedly on multiple inputs.