TransposeConvBiasOp class
Loads and provides access to the Convolution2DTransposeBias custom op.
This custom op is required for MediaPipe models like Selfie Segmentation.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- isLoaded → bool
-
Returns whether the custom op has been successfully loaded.
no setter
- isRegistered → bool
-
Returns whether the custom op has been registered with an interpreter options.
no setter
Static Methods
-
loadLibrary(
) → void - Loads the custom ops library.
-
registerWithOptions(
Pointer< TfLiteInterpreterOptions> options) → void - Registers the Convolution2DTransposeBias custom op with the given interpreter options.